﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Windows.Themes;
using System.ComponentModel;
using System.Collections.ObjectModel;
using Infragistics.Windows.DockManager;

namespace DockWithTheme
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            combo.ItemsSource = ThemeManager.GetThemes(true, ThemeManager.AllGroupingsLiteral).ToList();
            

            DataContext = new FileSystemViewModel();
        }

        private void combo_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            ThemeManager.CurrentTheme = e.AddedItems[0].ToString();
        }
    }

    public class DataToPanesConverter : IMultiValueConverter
    {
        public object Convert(object[] values, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            ObservableCollection<File> files = values[0] as ObservableCollection<File>;
            TabGroupPane documents = values[1] as TabGroupPane;

            if (files != null && documents != null)
            {
                //The bellow lines are removing the panes of the TabGroupPane
                //int count = documents.Items.Count;
                //for (int i = 0; i < count; i++)
                //{
                //    documents.Items.RemoveAt(0);
                //}

                foreach (File file in files)
                {
                    Grid content = new Grid();
                    content.RowDefinitions.Add(new RowDefinition { Height = new GridLength(1, GridUnitType.Auto) });
                    content.RowDefinitions.Add(new RowDefinition { Height = new GridLength(1, GridUnitType.Auto) });
                    content.RowDefinitions.Add(new RowDefinition { Height = new GridLength(1, GridUnitType.Star) });

                    StackPanel name = new StackPanel { Orientation = System.Windows.Controls.Orientation.Horizontal };
                    name.Children.Add(new TextBlock { Text = "Name : ", Width = 100 });
                    TextBox fName = new TextBox { Width = 150 };
                    fName.SetBinding(TextBox.TextProperty, new Binding("FileName") { Source = file, Mode = BindingMode.TwoWay });
                    name.Children.Add(fName);
                    content.Children.Add(name);

                    StackPanel size = new StackPanel { Orientation = System.Windows.Controls.Orientation.Horizontal };
                    Grid.SetRow(size, 1);
                    size.Children.Add(new TextBlock { Text = "Size : ", Width = 100 });
                    TextBox fsize = new TextBox { Width = 150 };
                    fsize.SetBinding(TextBox.TextProperty, new Binding("Size") { Source = file, Mode = BindingMode.TwoWay });
                    size.Children.Add(fsize);
                    content.Children.Add(size);


                    StackPanel cont = new StackPanel { Orientation = System.Windows.Controls.Orientation.Horizontal };
                    Grid.SetRow(cont, 2);
                    cont.Children.Add(new TextBlock { Text = "Name : ", Width = 100 });
                    TextBox fcont = new TextBox { Width = 150 };
                    fcont.SetBinding(TextBox.TextProperty, new Binding("Content") { Source = file, Mode = BindingMode.TwoWay });
                    cont.Children.Add(fcont);
                    content.Children.Add(cont);

                    ContentPane pane = new ContentPane
                    {
                        Header = file.FileName,
                        AllowDockingFloating = false,
                        Content = content
                    };

                    documents.Items.Add(pane);
                }
            }

            return null;
        }

        public object[] ConvertBack(object value, Type[] targetTypes, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }

    public class FileSystemViewModel : PropertyChangedNotifier
    {
        private object activeItem;
        private ObservableCollection<Folder> fileSystem;
        private ObservableCollection<File> filesCollection;

        public FileSystemViewModel()
        {
            Random r = new Random();
            FileSystem = new ObservableCollection<Folder>();
            for (int i = 0; i < 5; i++)
            {
                Folder folder = new Folder
                {
                    FolderName = "Folder " + i,
                    Files = new ObservableCollection<File>()
                };

                for (int j = 0; j < 5; j++)
                {
                    folder.Files.Add(new File 
                    {
                        FileName = "file " + i + " : " + j,
                        Size = r.Next(200) + r.NextDouble(),
                        Content = "content for file " + i,
                    });
                }

                FileSystem.Add(folder);
               
            }
            ActiveItem = FileSystem[0];
        }

        public ObservableCollection<Folder> FileSystem
        {
            get { return fileSystem; }
            set { fileSystem = value; OnPropertyChagned("FileSystem"); }
        }

        public object ActiveItem
        {
            get { return activeItem; }
            set 
            {
                activeItem = value;
                OnPropertyChagned("ActiveItem");

                if (activeItem is File)
                    ActiveFiles = new ObservableCollection<File> { activeItem  as File };
                if (activeItem is Folder)
                    ActiveFiles = (activeItem as Folder).Files;
            }
        }

        public ObservableCollection<File> ActiveFiles
        {
            get { return filesCollection; }
            set 
            {
                filesCollection = value;
                OnPropertyChagned("ActiveFiles");
            }
        }
    }

    public class Folder : PropertyChangedNotifier
    {
        private string fName;
        private ObservableCollection<File> files;

        public string FolderName
        {
            get { return fName; }
            set { fName = value; OnPropertyChagned("FolderName"); }
        }

        public ObservableCollection<File> Files
        {
            get { return files; }
            set { files = value; OnPropertyChagned("Files"); }
        }
    }

    public class File : PropertyChangedNotifier
    {
        private string fName;

        public string FileName
        {
            get { return fName; }
            set { fName = value; OnPropertyChagned("FileName"); }
        }

        private double size;

        public double Size
        {
            get { return size; }
            set { size = value; OnPropertyChagned("Size"); }
        }

        private string content;

        public string Content
        {
            get { return content; }
            set { content = value; OnPropertyChagned("Content"); }
        }


    }

    public class PropertyChangedNotifier : INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;

        public void OnPropertyChagned(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }
    }
}
